@@ -20,6 +20,15 @@ Ext.define('Traccar.store.MapTypes', {
     fields: ['key', 'name'],
 
     data: [{
+        key: 'locationIqStreets',
+        name: Strings.mapLocationIqStreets
+    }, {
+        key: 'locationIqEarth',
+        name: Strings.mapLocationIqEarth
+    }, {
+        key: 'locationIqHybrid',
+        name: Strings.mapLocationIqHybrid
+    }, {
         key: 'osm',
         name: Strings.mapOsm
     }, {
