@@ -527,6 +527,12 @@ Ext.define('Traccar.view.ReportController', {
         renderer: function (value) {
             return Traccar.app.getEventString(value);
         }
+    }, {
+        text: Strings.positionAlarm,
+        dataIndex: 'attributes',
+        renderer: function (value) {
+            return value['alarm'];
+        }
     }, {
         text: Strings.sharedGeofence,
         dataIndex: 'geofenceId',
