@@ -65,6 +65,13 @@ Ext.define('Traccar.view.map.Map', {
             pressed: true,
             stateId: 'show-geofences-button',
             tooltip: Strings.sharedGeofences
+        }, {
+            handler: 'showAccuracy',
+            reference: 'showAccuracyButton',
+            glyph: 'xf140@FontAwesome',
+            pressed: true,
+            stateId: 'show-accuracy-button',
+            tooltip: Strings.positionAccuracy
         }, {
             handler: 'showCurrentLocation',
             glyph: 'xf124@FontAwesome',
@@ -95,6 +102,10 @@ Ext.define('Traccar.view.map.Map', {
         return this.accuracySource;
     },
 
+    getAccuracyLayer: function () {
+        return this.accuracyLayer;
+    },
+
     getRouteSource: function () {
         return this.routeSource;
     },
@@ -133,10 +144,11 @@ Ext.define('Traccar.view.map.Map', {
         }));
 
         this.accuracySource = new ol.source.Vector({});
-        this.map.addLayer(new ol.layer.Vector({
+        this.accuracyLayer = new ol.layer.Vector({
             name: 'accuracyLayer',
             source: this.accuracySource
-        }));
+        });
+        this.map.addLayer(this.accuracyLayer);
 
         this.markersSource = new ol.source.Vector({});
         this.map.addLayer(new ol.layer.Vector({
